@@ -9,11 +9,11 @@ from typing import Any, TypeVar
 T = TypeVar('T')
 
 
-def interned(cls: type[T]) -> type[T]:
+def interned(class_: type[T]) -> type[T]:
     cache: dict[tuple, T] = {}
-    original_new = cls.__new__
+    original_new = class_.__new__
 
-    def __new__(cls, *args, **kwargs):
+    def caching_new(cls: type[T], *args: Any, **kwargs: Any) -> T:
         arguments = _get_arguments(cls, *args, **kwargs)
 
         key = tuple(arguments.values())
@@ -27,12 +27,14 @@ def interned(cls: type[T]) -> type[T]:
         cache[key] = instance
         return instance
 
-    cls.__new__ = __new__  # type: ignore[method-assign]
-    return cls
+    setattr(class_, '__new__', caching_new)
+    return class_
 
 
-def _get_arguments(cls: type, *args, **kwargs) -> OrderedDict[str, Any]:
-    init_signature = inspect.signature(cls.__init__)  # type: ignore[misc]
+def _get_arguments(
+    class_: type, *args: Any, **kwargs: Any
+) -> OrderedDict[str, Any]:
+    init_signature = inspect.signature(class_.__init__)  # type: ignore[misc]
     bound_arguments = init_signature.bind(None, *args, **kwargs)
     bound_arguments.apply_defaults()
     bound_arguments.arguments.pop('self')
